@@ -7,6 +7,7 @@ from jamstats.util.resources import (
     get_jamstats_logo_image, get_jamstats_version
 )
 import inspect
+import os
 
 
 from jamstats.plots.jamplots import (
@@ -34,7 +35,9 @@ import logging
 import socket
 
 
-MIN_REQUERY_SERVER_SECONDS = 30
+MIN_REQUERY_SERVER_SECONDS = 29
+
+DEFAULT_AUTOREFRESH_SECONDS = 30
 
 logger = logging.Logger(__name__)
 
@@ -77,6 +80,7 @@ def start(port: int, jamstats_ip: str = None, debug: bool = True, scoreboard_ser
     prepare_to_plot(theme=theme)
     app.scoreboard_server = scoreboard_server
     app.scoreboard_port = scoreboard_port
+    app.autorefresh_seconds = DEFAULT_AUTOREFRESH_SECONDS
     if jamstats_ip:
         app.ip = jamstats_ip
     else:
@@ -119,9 +123,17 @@ def index():
 
     game_update_time_str = app.game_update_time.strftime("%Y-%m-%d, %H:%M:%S")
 
-    return render_template_string(f'''<!doctype html>
+    return render_template_string(f'''<!DOCTYPE html>
     <html>
         <head title="Jamstats">
+            <script type="text/javascript">
+            setTimeout(function () {{
+                  location.reload();
+                }}, {1000 * app.autorefresh_seconds});
+            </script>
+            <noscript>
+                <meta http-equiv="refresh" content="{app.autorefresh_seconds}" />
+            </noscript>
         </head>
         <body>
             <table>
@@ -143,15 +155,20 @@ def index():
                             </tr>
                             <tr>
                                 <th align="left" valign="top" bgcolor="gray" width="200">
-                                    <p>jamstats server:port :</p>
-                                    <p>{app.ip}:{app.port}</p>
+                                    <p>jamstats server/port:
+                                    <br/>
+                                    {app.ip}:{app.port}</p>
+                                </th>
+                            </tr>
+                            <tr>
+                                <th align="left" valign="top" bgcolor="gray" width="200">
+                                    <p>Page will refresh every {app.autorefresh_seconds} seconds</p>
                                 </th>
                             </tr>
                         </table>
                     </th>
                     <th>
-                        <p><H2>{plot_name}</H2></p>
-                        <p><img src="fig/{plot_name}" width="1000"/></p>
+                        {generate_figure_html(app, plot_name)}
                     </th>
                 </tr>
             </table>
@@ -159,11 +176,32 @@ def index():
     </html>
     ''')
 
+
 @app.route("/logo")
 def show_logo():
     # add logo to table plots
     return send_file(io.BytesIO(get_jamstats_logo_image()), mimetype='image/png')
 
+
+def generate_figure_html(app, plot_name: str) -> str:
+    """Generate HTML for a figure.
+
+    If a derby game isn't loaded, return a message saying so.
+
+    Args:
+        app: server app
+        plot_name (str): name of plot to generate
+
+    Returns:
+        str: HTML for the plot
+    """
+    if app.derby_game is None:
+        return "No derby game available..."
+
+    return (f"<p><H2>{plot_name}</H2></p>\n" +
+            f'<p><img src="fig/{plot_name}" width="1000"/></p>\n')
+
+
 @app.route("/fig/<plot_name>")
 def plot_figure(plot_name: str):
     """Plot a figure.
